<h1>cat2</h1>
<h2>Print file contents like a boss</h2>

<img src="https://i.ibb.co/XFgv40n/Screen-Shot-2018-12-01-at-21-50-08.png">
<img src="https://i.ibb.co/qJYt2nH/Screen-Shot-2018-12-01-at-21-50-45.png">
<img src="https://i.ibb.co/hCRcTsv/Screen-Shot-2018-12-01-at-21-55-05.png">
<img src="https://i.ibb.co/FVXJNQ6/Screen-Shot-2018-12-01-at-21-55-18.png">